@@ -9,11 +9,11 @@ A Python tool for running OCR on Pokemon Screenshots using Google Cloud Vision
 
 """
 
-__title__ = 'PogoOCR'
-__author__ = 'JayTurnr'
-__licence__ = 'GNU GENERAL PUBLIC LICENSE 3.0'
-__copyright__ = '2020 TrainerDex'
-__version__ = '0.3.1'
+__title__ = "PogoOCR"
+__author__ = "JayTurnr"
+__licence__ = "GNU GENERAL PUBLIC LICENSE 3.0"
+__copyright__ = "2020 TrainerDex"
+__version__ = "0.3.2.post2"
 
 from .cloudvision import Image
-from .types import ProfileSelf, Badge, Pokédex
+from .types import ProfileSelf
